import { FSJetpack } from "fs-jetpack/types";
import ts from "typescript";
import { FullConfig } from "./types";
export declare type StoreInfo = {
    filePath?: string;
    name?: string;
    /**
     * The name of the class that extends Store
     */
    className?: string;
    /**
     * If the dev defined `public static vueBinding = 'x';` in their store, this will hold that value
     */
    vueBinding?: string;
    /**
     * This will hold the name of our store export `export const store = new MyStore();`
     */
    exportName?: string;
};
export declare class Context {
    program: ts.Program;
    /**
     * File paths to all files in the project(loaded by typescript compiler)
     * @type {string[]}
     */
    filePaths: string[];
    /**
     * File paths to all of our store files in the project
     * @type {string[]}
     */
    storeFilePaths: string[];
    /**
     * When we first load our stores, we'll take a hash of the content
     * Later on this hash will be used when there is a change, mainly to
     * determine if we need to do some file writes, when writing stores.d.ts,
     * even if contents are the same, this makes vite do a full page reload...
     * @type {Map<string, string>}
     */
    storeFileHashes: Map<string, string>;
    /**
     * All of the store modules in our project
     *
     * @type {{module: ts.SourceFile, store: StoreMeta}[]}
     */
    modules: {
        module: ts.SourceFile;
        store: StoreMeta;
    }[];
    stores: StoreMeta[];
    config: Partial<FullConfig>;
    compilerHost: ts.CompilerHost;
    printer: ts.Printer;
    typeChecker: ts.TypeChecker;
    parsedCommandLine: ts.ParsedCommandLine;
    static instance: Context;
    /**
     * This is the directory where all of our generated files will be stored
     * @type {FSJetpack}
     * @private
     */
    generatedDir: FSJetpack;
    init(pluginConfig: Partial<FullConfig>): void;
    /**
     * Set the store file paths & all project file paths
     *
     * @returns {string[]}
     */
    setFilePaths(): string[];
    /**
     * Load all of our store modules and create a "store meta" class.
     */
    reloadModules(reloadFilePaths?: boolean): void;
    private addFileHash;
    private loadGeneratedFileHash;
    /**
     * MAKE SURE TO PASS A FULL ABSOLUTE PATH TO THIS METHOD!
     *
     * @param {string} filePath
     * @returns {boolean}
     * @private
     */
    private fileHasChanged;
    process(): void;
    writeFiles(): void;
    private writeStoreDeclaration;
    rebuild(): void;
    private processModule;
    isStoreFile(path: string): boolean;
    getStoreByFilePath(path: string): StoreMeta | undefined;
    private writeTsFile;
    private writeFile;
    static printNode(node: any): void;
}
export declare class StoreMeta {
    /**
     * The absolute path to the store file
     */
    absFilePath: string;
    /**
     * The relative path of the store file, for ex, if importing in /src/stores/, and our file is at /src/stores/MyStore.ts, this will be MyStore.ts
     */
    relStoreFilePath: string;
    /**
     * The relative import path from Stores/.generated/StoreLoader.ts to the store location
     * @type {string}
     */
    loaderImportPath: string;
    /**
     * The name of the store file
     */
    name: string;
    /**
     * The name of the class that extends Store
     */
    className?: string;
    /**
     * This will hold the name of our store export `export const store = new MyStore();`
     */
    exportName?: string;
    /**
     * If the dev defined `public static vueBinding = 'x';` in their store, this will hold that value
     */
    vueBinding?: string;
    actions: ActionMeta[];
    constructor(file: ts.SourceFile, absStoresPath: string);
    isValid(): boolean;
    finalize(): this;
    private formatVueBinding;
    metaObject(includeImport?: boolean): {
        className: string;
        importPath: string;
        exportName: string;
        vueBinding: string;
        actions: any;
        module: import("./Builders/Object").UnwrappableNode;
    };
}
declare class ActionMeta {
    name: string;
    params: any[];
    private method;
    private signature;
    constructor(method: ts.MethodDeclaration, name: string);
    toJSON(): {
        name: string;
        params: any[];
    };
}
export {};
